aboutsummaryrefslogtreecommitdiff
path: root/scripts
diff options
context:
space:
mode:
authorShaun Case <warmsocks@gmail.com>2021-12-20 21:14:10 -0800
committerDave Rodgman <dave.rodgman@arm.com>2022-05-11 21:25:51 +0100
commit8b0ecbccf465c5c795e6d2898e6af2b9af14b83c (patch)
treeb728fc64e508f4c117b2dc141bd8fd338401669a /scripts
parent5479f5321aca0b08762074372e22f2c0033d939d (diff)
downloadmbedtls-8b0ecbccf465c5c795e6d2898e6af2b9af14b83c.zip
mbedtls-8b0ecbccf465c5c795e6d2898e6af2b9af14b83c.tar.gz
mbedtls-8b0ecbccf465c5c795e6d2898e6af2b9af14b83c.tar.bz2
Redo of PR#5345. Fixed spelling and typographical errors found by CodeSpell.
Signed-off-by: Shaun Case <warmsocks@gmail.com> Signed-off-by: Dave Rodgman <dave.rodgman@arm.com>
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/code_size_compare.py6
-rwxr-xr-xscripts/config.py2
-rwxr-xr-xscripts/generate_ssl_debug_helpers.py2
3 files changed, 5 insertions, 5 deletions
diff --git a/scripts/config.py b/scripts/config.py
index c09212b..356b998 100755
--- a/scripts/config.py
+++ b/scripts/config.py
@@ -418,7 +418,7 @@ class ConfigFile(Config):
value = setting.value
if value is None:
value = ''
- # Normally the whitespace to separte the symbol name from the
+ # Normally the whitespace to separate the symbol name from the
# value is part of middle, and there's no whitespace for a symbol
# with no value. But if a symbol has been changed from having a
# value to not having one, the whitespace is wrong, so fix it.
diff --git a/scripts/generate_ssl_debug_helpers.py b/scripts/generate_ssl_debug_helpers.py
index 4be6fd6..1dc75c8 100755
--- a/scripts/generate_ssl_debug_helpers.py
+++ b/scripts/generate_ssl_debug_helpers.py
@@ -53,7 +53,7 @@ def preprocess_c_source_code(source, *classes):
"""
Simple preprocessor for C source code.
- Only processses condition directives without expanding them.
+ Only processes condition directives without expanding them.
Yield object according to the classes input. Most match firstly
If the directive pair does not match , raise CondDirectiveNotMatch.
diff --git a/scripts/code_size_compare.py b/scripts/code_size_compare.py
index 85393d0..0ef438d 100755
--- a/scripts/code_size_compare.py
+++ b/scripts/code_size_compare.py
@@ -37,7 +37,7 @@ class CodeSizeComparison:
"""
old_revision: revision to compare against
new_revision:
result_dir: directory for comparision result
"""
self.repo_path = "."
self.result_dir = os.path.abspath(result_dir)
@@ -140,7 +140,7 @@ class CodeSizeComparison:
+ "-" + self.new_rev + ".csv"), "w")
res_file.write("file_name, this_size, old_size, change, change %\n")
- print("Generating comparision results.")
+ print("Generating comparison results.")
old_ds = {}
for line in old_file.readlines()[1:]:
@@ -199,7 +199,7 @@ def main():
parser.add_argument(
"-n", "--new-rev", type=str, default=None,
help="new revision for comparison, default is the current work \
- directory, including uncommited changes."
+ directory, including uncommitted changes."
)
comp_args = parser.parse_args()
@@ -37,7 +37,7 @@ class CodeSizeComparison:
old_revision: revision to compare against
new_revision:
- result_dir: directory for comparision result
+ result_dir: directory for comparison result
"""
self.repo_path = "."